==> audit-1.1.1.tgz: package/lib/audit/__tests__/audit.logic.spec.js <==
/* eslint global-require: 0 */

describe('Audit Logic', () => {

    afterEach(() => {
        jest.resetModules();
    });

    describe('store', () => {
        it('should correct extract data', async () => {
            const storeData = {
                metainfo: {
                    userId: 'testUserID',
                    accountId: 'testAccountID',
                    entity: 'testEntity',
                    action: 'testAction',
                    entityId: 'testEntityId',
                    entityName: 'testEntityName',
                    userEmail: 'testUserEmail',
                    userName: 'testUserName'
                },
                request: {
                    url: 'testUrl',
                    body: { test: 1 },
                    query: { query: 1 },
                    params: { params: 1 }
                },
                response: {
                    status: 200
                }
            };

            jest.mock('../../models', () => {
                return {
                    Audit: {
                        create(data) {
                            delete data.createdAt;
                            expect(data).toEqual(
                                {
                                    'accountId': 'testAccountID',
                                    'action': 'testAction',
                                    'entity': 'testEntity',
                                    'entityId': 'testEntityId',
                                    'entityName': 'testEntityName',
                                    'req_body': '{"test":1}',
                                    'req_params': '{"params":1}',
                                    'req_query': '{"query":1}',
                                    'req_url': 'testUrl',
                                    'rs_status': 200,
                                    'userEmail': 'testUserEmail',
                                    'userId': 'testUserID',
                                    'userName': 'testUserName'
                                }
                            );
                        }
                    }
                };
            });

            const audit = require('../../index');
            await audit.store(storeData);
        });
    });

    describe('getAudit', () => {
        it('should return correct audit data', async () => {
            jest.mock('../../models', () => {
                return {
                    Audit: {
                        findAndCountAll() {
                            return Promise.resolve({
                                count: 1,
                                rows: [{ _id: 'testID', action: 'testAction' }]
                            });
                        }
                    }
                };
            });

            const audit = require('../../index');
            const result = await audit.getAudit({});

            expect(result).toEqual({
                rows: [{ _id: 'testID', action: 'testAction' }],
                count: 1
            });
        });
    });

    describe('getUserNames', () => {
        it('should return correct names', async () => {
            jest.mock('../../models', () => {
                return {
                    Audit: {
                        aggregate() {
                            return [{ DISTINCT: 'userName1' }, { DISTINCT: 'userName2' }];
                        }
                    }
                };
            });

            const audit = require('../../index');
            const result = await audit.getUserNames();

            expect(result).toEqual(['userName1', 'userName2']);
        });
    });

    describe('getEntitiesList', () => {
        it('should return correct list', async () => {
            jest.mock('../../models', () => {
                return {
                    Audit: {
                        findAll(opts) {
                            expect(opts).toEqual({
                                where: { accountId: 'testAccId' },
                                attributes: ['entity', 'action'],
                                distinct: true,
                                raw: true
                            });
                            return Promise.resolve([
                                { entity: 'entity1', action: 'action1' },
                                { entity: 'entity2', action: 'action2' },
                            ]);
                        }
                    }
                };
            });

            const audit = require('../../index');
            const result = await audit.getEntitiesList('testAccId');

            expect(result).toEqual({
                entity1: ['action1'],
                entity2: ['action2']
            });
        });
    });
});

==> audit-1.1.3.tgz: package/lib/audit/__tests__/audit.logic.spec.js <==
/* eslint global-require: 0 */

describe('Audit Logic', () => {

    afterEach(() => {
        jest.resetModules();
    });

    describe('store', () => {
        it('should correct extract data', async () => {
            const storeData = {
                metainfo: {
                    userId: 'testUserID',
                    accountId: 'testAccountID',
                    entity: 'testEntity',
                    action: 'testAction',
                    entityId: 'testEntityId',
                    entityName: 'testEntityName',
                    userEmail: 'testUserEmail',
                    userName: 'testUserName'
                },
                request: {
                    url: 'testUrl',
                    body: { test: 1 },
                    query: { query: 1 },
                    params: { params: 1 }
                },
                response: {
                    status: 200
                }
            };

            jest.mock('../../models', () => {
                return {
                    Audit: {
                        create(data) {
                            delete data.createdAt;
                            expect(data).toEqual(
                                {
                                    'accountId': 'testAccountID',
                                    'action': 'testAction',
                                    'entity': 'testEntity',
                                    'entityId': 'testEntityId',
                                    'entityName': 'testEntityName',
                                    'req_body': '{"test":1}',
                                    'req_params': '{"params":1}',
                                    'req_query': '{"query":1}',
                                    'req_url': 'testUrl',
                                    'rs_status': 200,
                                    'userEmail': 'testUserEmail',
                                    'userId': 'testUserID',
                                    'userName': 'testUserName'
                                }
                            );
                        }
                    }
                };
            });

            const audit = require('../../index');
            await audit.store(storeData);
        });
    });

    describe('getAudit', () => {
        it('should return correct audit data', async () => {
            jest.mock('../../models', () => {
                return {
                    Audit: {
                        findAndCountAll() {
                            return Promise.resolve({
                                count: 1,
                                rows: [{ _id: 'testID', action: 'testAction' }]
                            });
                        }
                    }
                };
            });

            const audit = require('../../index');
            const result = await audit.getAudit({});

            expect(result).toEqual({
                rows: [{ _id: 'testID', action: 'testAction' }],
                count: 1
            });
        });
    });

    describe('getUserNames', () => {
        it('should return correct names', async () => {
            jest.mock('../../models', () => {
                return {
                    Audit: {
                        aggregate() {
                            return [{ DISTINCT: 'userName1' }, { DISTINCT: 'userName2' }];
                        }
                    }
                };
            });

            const audit = require('../../index');
            const result = await audit.getUserNames();

            expect(result).toEqual(['userName1', 'userName2']);
        });
    });

    describe('getEntitiesList', () => {
        it('should return correct list', async () => {
            jest.mock('../../models', () => {
                return {
                    Audit: {
                        findAll(opts) {
                            expect(opts).toEqual({
                                where: {
                                    accountId: 'testAccId',
                                    action: { [require('sequelize').Op.ne]: 'receiveWebhook' }
                                },
                                attributes: ['entity', 'action'],
                                distinct: true,
                                raw: true
                            });
                            return Promise.resolve([
                                { entity: 'entity1', action: 'action1' },
                                { entity: 'entity2', action: 'action2' },
                            ]);
                        }
                    }
                };
            });

            const audit = require('../../index');
            const result = await audit.getEntitiesList('testAccId', {});

            expect(result).toEqual({
                entity1: ['action1'],
                entity2: ['action2']
            });
        });

        it('should handle tab option', async () => {
            jest.mock('../../models', () => {
                return {
                    Audit: {
                        findAll(opts) {
                            expect(opts).toEqual({
                                where: { accountId: 'testAccId', action: 'receiveWebhook' },
                                attributes: ['entity', 'action'],
                                distinct: true,
                                raw: true
                            });
                            return Promise.resolve([
                                { entity: 'entity1', action: 'action1' },
                                { entity: 'entity2', action: 'action2' },
                            ]);
                        }
                    }
                };
            });

            const audit = require('../../index');
            const result = await audit.getEntitiesList('testAccId', { showTriggers: 'true' });

            expect(result).toEqual({
                entity1: ['action1'],
                entity2: ['action2']
            });
        });
    });
});
